# count

# 莱布尼茨级数法计算 π
def leibniz(iterations: int) -> float: ...

# 马青公式法计算 π
def machin(iterations: int) -> float: ...

# 拉马努金公式法计算 π
def ramanujan(iterations: int) -> float: ...

# BBP 公式计算 π
def bbp(iterations: int) -> float: ...

# 计算阶乘的函数
def factorial(n: int) -> float: ...

# 计算正弦函数
def sin(x: float) -> float: ...

# 计算余弦函数
def cos(x: float) -> float: ...

# 计算正切函数
def tan(x: float) -> float: ...

# 计算余切函数
def cot(x: float) -> float: ...